@@ -623,6 +623,7 @@ def bronze_to_silver(
     tbl_properties=None,
     sort_fields: list = None,
     upsert_fields: list = None,
+    governance_options=None
 ):
     if spark is None:
         spark = get_spark_session(app_name=dataset_name)
@@ -702,6 +703,47 @@ def bronze_to_silver(
             df=df, data_pack_name=data_pack_name, dataset_name=dataset_name, layer="silver"
         )
 
+    if governance_options:
+        if tbl_properties:
+            try:
+                columns = [
+                            'id_datapack',
+                            'table_name',
+                            'description',
+                            'security_level',
+                            'data_owner',
+                            'cycle_collection',
+                            'volumetry',
+                            'columns_count',
+                            'rows_count',
+                            'last_update',
+                            'create_date'
+                        ]
+                values = [
+                        (
+                            tbl_properties.get('cortex.source'),
+                            tbl_properties.get('cortex.tableName'),
+                            tbl_properties.get('cortex.description'),
+                            tbl_properties.get('cortex.securityLevel'),
+                            tbl_properties.get('cortex.dataOwner'),
+                            tbl_properties.get('cortex.cycleCollection'),
+                            tbl_properties.get('cortex.volumetry'),
+                            tbl_properties.get('cortex.columnsCount'),
+                            tbl_properties.get('cortex.rowsCount'),
+                            tbl_properties.get('cortex.lastUpdate'),
+                            tbl_properties.get('cortex.createDate'),
+                        )
+                    ]
+                df_governance = spark.createDataFrame(values, columns)
+                df_governance.write.option("header", "true")\
+                    .format('delta')\
+                    .mode('append')\
+                    .saveAsTable("cortex.data_governance_quality.datasets")
+
+            except Exception as e:
+                print(e)
+        else: 
+            print("ERROR : properties not found")
     return True
 
 
@@ -727,6 +769,7 @@ def silver_to_gold(
     catalog_name=None,
     where=None,
     tbl_properties=None,
+    governance_options=None,
 ):
     if spark is None:
         spark = get_spark_session(app_name=dataset_name)
@@ -805,6 +848,53 @@ def silver_to_gold(
         apply_profiling(
             df=df, data_pack_name=data_pack_name, dataset_name=dataset_name, layer="gold"
         )
+    if governance_options:
+        if tbl_properties:
+            try:
+                columns = [
+                            'id_datapack',
+                            'table_name',
+                            'description',
+                            'security_level',
+                            'data_owner',
+                            'cycle_collection',
+                            'volumetry',
+                            'columns_count',
+                            'rows_count',
+                            'last_update',
+                            'create_date',
+                            'exposures'
+                        ]
+                values = [
+                        (
+                            tbl_properties.get('cortex.source'),
+                            tbl_properties.get('cortex.tableName'),
+                            tbl_properties.get('cortex.description'),
+                            tbl_properties.get('cortex.securityLevel'),
+                            tbl_properties.get('cortex.dataOwner'),
+                            tbl_properties.get('cortex.cycleCollection'),
+                            tbl_properties.get('cortex.volumetry'),
+                            tbl_properties.get('cortex.columnsCount'),
+                            tbl_properties.get('cortex.rowsCount'),
+                            tbl_properties.get('cortex.lastUpdate'),
+                            tbl_properties.get('cortex.createDate'),
+                            tbl_properties.get('cortex.exposures')
+                        )
+                    ]
+                df_governance = spark.createDataFrame(values, columns)
+                df_governance.write.option("header", "true")\
+                    .format('delta')\
+                    .mode('append')\
+                    .saveAsTable("cortex.data_governance_quality.datasets")
+
+            except Exception as e:
+                print(e)
+        else: 
+            print("ERROR : properties not found")
+
+        
+
+
 
 @__verify_parameters
 def gold_to_diamond(
